Update Variable Naming Convention

Variables in qemu-build.sh, build-jenkins.sh, build-setup.sh,
and kubernetes-launch.sh updated to use the same convention across
different scripts.

Change-Id: Ice9ef2f47b0fbf125eadd235f63b79abafdc2dd7
Signed-off-by: Alanny Lopez <alannyglopez@gmail.com>
diff --git a/build-jenkins.sh b/build-jenkins.sh
index 9d41bc9..341f89a 100755
--- a/build-jenkins.sh
+++ b/build-jenkins.sh
@@ -33,7 +33,7 @@
 #                     Default: "1000"
 #  j_home             Directory used as the Jenkins Home in the container.
 #                     Default: "/var/jenkins_home"
 #  out_img            The name given to the Docker image when it is built.
 #                     Default: "openbmc/jenkins-master-${ARCH}:${JENKINS_VRSN}"
 #  tini_vrsn          The version of Tini to use in the Dockerfile, 0.16.1 is
 #                     the first release with ppc64le release support.
@@ -84,7 +84,7 @@
 j_home=${j_home:-/var/jenkins_home}
 http_port=${http_port:-8080}
 agent_port=${agent_port:-50000}
-out_img=${out_img:-openbmc/jenkins-master-${ARCH}:${j_vrsn}}
+img_name=${img_name:-openbmc/jenkins-master-${ARCH}:${j_vrsn}}
 
 # Save the Jenkins.war URL to a variable and SHA if we care about verification
 j_url=https://repo.jenkins-ci.org/public/org/jenkins-ci/main/jenkins-war/${j_vrsn}/jenkins-war-${j_vrsn}.war
@@ -199,7 +199,7 @@
 ################################################################################
 
 # Build the image
-docker build -t ${out_img} .
+docker build -t ${img_name} .
 
 if [[ ${launch} == "docker" ]]; then
 
@@ -215,22 +215,22 @@
   # Ensure directories tht will be mounted are owned by the jenkins user
   if [[ "$(id -u)" != 0 ]]; then
     echo "Not running as root:"
-    echo "Checking if jgid and juid are the owners of mounted directories"
-    test1=$(ls -nd ${home_mnt} | awk '{print $3 " " $4}')
-    if [[ "${test1}" != "${j_uid} ${j_gid}" ]]; then
+    echo "Checking if j_gid and j_uid are the owners of mounted directories"
+    test_1=$(ls -nd ${home_mnt} | awk '{print $3 " " $4}')
+    if [[ "${test_1}" != "${j_uid} ${j_gid}" ]]; then
       echo "Owner of ${home_mnt} is not the jenkins user"
-      echo "${test1} != ${j_uid} ${j_gid}"
-      willfail=1
+      echo "${test_1} != ${j_uid} ${j_gid}"
+      will_fail=1
     fi
     if [[ ! -z "${host_import_mnt}" ]]; then
-      test2=$(ls -nd ${host_import_mnt} | awk '{print $3 " " $4}' )
-      if [[ "${test2}" != "${j_uid} ${j_gid}" ]]; then
+      test_2=$(ls -nd ${host_import_mnt} | awk '{print $3 " " $4}' )
+      if [[ "${test_2}" != "${j_uid} ${j_gid}" ]]; then
         echo "Owner of ${host_import_mnt} is not the jenkins user"
-        echo "${test2} != ${j_uid} ${j_gid}"
-        willfail=1
+        echo "${test_2} != ${j_uid} ${j_gid}"
+        will_fail=1
       fi
     fi
-    if [[ "${willfail}" == 1 ]]; then
+    if [[ "${will_fail}" == 1 ]]; then
       echo "Failing before attempting to launch container"
       echo "Try again as root or use correct uid/gid pairs"
       exit 1
@@ -244,17 +244,17 @@
 
   #If we don't have import mount don't add to docker command
   if [[ ! -z ${host_import_mnt} ]]; then
-   importvolcmd="-v ${host_import_mnt}:${cont_import_mnt}"
+   import_vol_cmd="-v ${host_import_mnt}:${cont_import_mnt}"
   fi
   # Launch the jenkins image with Docker
   docker run -d \
-    ${importvolcmd} \
+    ${import_vol_cmd} \
     -v ${home_mnt}:${j_home} \
     -p ${http_port}:8080 \
     -p ${agent_port}:${agent_port} \
     --env JAVA_OPTS=\"${java_options}\" \
     --env JENKINS_OPTS=\"${jenkins_options}\" \
-    ${out_img}
+    ${img_name}
 
 elif [[ ${launch} == "k8s" ]]; then
   # launch using the k8s template
@@ -33,7 +33,7 @@
 #  j_home             Directory used as the Jenkins Home in the container.
 #                     Default: "/var/jenkins_home"
-#  out_img            The name given to the Docker image when it is built.
+#  img_name           The name given to the Docker image when it is built.
 #                     Default: "openbmc/jenkins-master-${ARCH}:${JENKINS_VRSN}"
 #  tini_vrsn          The version of Tini to use in the Dockerfile, 0.16.1 is